package Perinci::Examples::Bin::Lite;

our $DATE = '2014-10-24'; # DATE
our $VERSION = '0.02'; # VERSION

use 5.010001;

1;
# ABSTRACT: Perinci example CLI scripts (using Perinci::CmdLine::Lite)

__END__

=pod

=encoding UTF-8

=head1 NAME

Perinci::Examples::Bin::Lite - Perinci example CLI scripts (using Perinci::CmdLine::Lite)

=head1 VERSION

This document describes version 0.02 of Perinci::Examples::Bin::Lite (from Perl distribution Perinci-Examples-Bin-Lite), released on 2014-10-24.

=head1 DESCRIPTION

This distribution contains example scripts in C<bin/> which use
L<Perinci::CmdLine::Lite>.

=head1 SEE ALSO

L<Perinci::Examples::Bin>

L<Perinci::Examples::Bin::Any>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples-Bin-Lite>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples-Bin-Lite>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples-Bin-Lite>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
